% This function creates a figure window number 1 and allows user to
% pick an arbitrary interface.
% Pressing the spacebar or clicking outside of the plot box 
% terminates the sequence of points.
% 
% On exist, picklayer does not close the figure window, so that 
% repeated calls to picklayer(width,height) will display previous picks as well
%
% A call picklayer() with no parameters will close the figure window.
%
% Parameters:
%   width and hight are the dimensions of the area,
%   layer1 and layer2 - optional layers picked previously. These layers are
%           only plotted in green and not edited
%
% Returns:
%   layer is array of picked points (each row contains x and y of picked point)
%       The points are sorted by increasing distances x.

function [layer] = picklayer(width,height,layer1,layer2)

  layer = [];       % initial empty array of points

  fig = figure(1);
    
  while true        % infinite loop waiting for user inputs
      
    clf
    hold on;
    axis([0,width,0,height]);   % plot range
    set(gca,'YDir','reverse');  % reverse the vertical axis
    xlabel('Distance (m)');
    ylabel('Depth (m)');
    title('Pick boundaries. Press spacebar or click outside of the plot box to finish');

               % plot previously picked layers

    if nargin > 2  
            plot(layer1(:,1),layer1(:,2),'g-');   
            plot(layer1(:,1),layer1(:,2),'go');
    end

    if nargin > 3  
            plot(layer1(:,1),layer2(:,2),'g-');   
            plot(layer1(:,1),layer2(:,2),'go');
    end

           % plot line and nodes
    
    if size(layer,1) > 1
      plot(layer(:,1),layer(:,2),'b-');
    end
    
    if size(layer,1) > 0
      plot(layer(:,1),layer(:,2),'bo');
    end
         % read mouse position (x,y) and key ptessed by the user 
  
    [ x, y, key ] = ginput(1);   
    
    if isempty(key)   % window closed
        return
    end
    
          % interpret user's action

    if x < 0 || x > width || y < 0 || y > height	% pick outside of plot range
	    break
    end
 
    switch key 
        case  32   % spacebar pressed - drop out of the loop
            break
        case 1      % left mouse button - pick a new point
              
            if isempty(layer)     % doing first point
                layer = [x,y];
            else                  % need to insert a point
                
                  % add a point at the end and then sort by X
              layer = [ layer; x, y ];      
              
              [xsort, ind] = sort(layer(:,1));
              
              layer = layer(ind,:);
            end
            
         otherwise
            continue
            
    end     % switch
 
  end   % big loop
   
  close(fig);
   
end   % function


